==========
Data types
==========
.. currentmodule:: polars

.. autosummary::
    :toctree: api/
    :nosignatures:

    DataType

Numeric
~~~~~~~
.. autosummary::
    :toctree: api/
    :nosignatures:

    Decimal
    Float32
    Float64
    Int8
    Int16
    Int32
    Int64
    UInt8
    UInt16
    UInt32
    UInt64

Temporal
~~~~~~~~~~~
.. autosummary::
    :toctree: api/
    :nosignatures:

    Date
    Datetime
    Duration
    Time

Nested
~~~~~~
.. autosummary::
    :toctree: api/

    Array
    List
    Struct

Other
~~~~~
.. autosummary::
    :toctree: api/
    :nosignatures:

    Boolean
    Binary
    Categorical
    Enum
    Null
    Object
    String
    Utf8
    Unknown
